@@ -434,16 +434,19 @@ void
 MainWindow::toggleLoadView()
 {
     if( m_mainView->currentWidget() == m_loadView ) {
-        if( engine()->state() != Phonon::StoppedState ) {
+        if (m_currentWidget && engine()->state() != Phonon::StoppedState) {
             if( m_mainView->indexOf(m_currentWidget) == -1 ) {
                 m_mainView->addWidget(m_currentWidget);
             }
             m_mainView->setCurrentWidget(m_currentWidget);
         }
+        if (engine()->state() == Phonon::StoppedState) {
+            m_loadView->setThumbnail(nullptr);
+        }
         engine()->isPreview(false);
     } else if( m_currentWidget != m_audioView ) {
         m_mainView->setCurrentWidget( m_loadView );
-        if( engine()->state() != Phonon::StoppedState ) {
+        if (m_currentWidget && engine()->state() != Phonon::StoppedState) {
             m_mainView->removeWidget(m_currentWidget);
             engine()->isPreview(true);
             m_loadView->setThumbnail(m_currentWidget);
@@ -836,7 +839,7 @@ MainWindow::inhibitPowerSave()
     // TODO: inhibit screen sleep. No viable API found.
     // https://git.reviewboard.kde.org/r/129651
     if (!m_stopScreenSaver && TheStream::hasVideo())
-        m_stopScreenSaver = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver);
+        m_stopScreenSaver = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver, i18nc("Notification inhibition reason", "playing a video"));
 }
 
 void
